@@ -1,5 +1,5 @@
 /* auditd-config.c -- 
- * Copyright 2007 Red Hat Inc., Durham, North Carolina.
+ * Copyright 2007,2014 Red Hat Inc., Durham, North Carolina.
  * All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,8 @@ struct nv_list
 	int option;
 };
 
-static char *get_line(FILE *f, char *buf);
+static char *get_line(FILE *f, char *buf, unsigned size, int *lineno,
+	const char *file);
 static int nv_split(char *buf, struct _pair *nv);
 static const struct kw_pair *kw_lookup(const char *val);
 static int log_file_parser(const char *val, int line, 
@@ -81,7 +82,7 @@ static const struct nv_list log_formats[] =
 /*
  * Set everything to its default value
 */
-static void clear_config(struct daemon_conf *config)
+void clear_config(struct daemon_conf *config)
 {
 	config->qos = QOS_NON_BLOCKING;
 	config->sender_uid = 0;
@@ -117,7 +118,7 @@ int load_config(struct daemon_conf *config, log_test_t lt)
 	int fd, rc, lineno = 1;
 	struct stat st;
 	FILE *f;
-	char buf[128];
+	char buf[160];
 
 	clear_config(config);
 	lt = lt;
@@ -167,7 +168,7 @@ int load_config(struct daemon_conf *config, log_test_t lt)
 		return 1;
 	}
 
-	while (get_line(f, buf)) {
+	while (get_line(f,  buf, sizeof(buf), &lineno, CONFIG_FILE)) {
 		// convert line into name-value pair
 		const struct kw_pair *kw;
 		struct _pair nv;
@@ -197,6 +198,9 @@ int load_config(struct daemon_conf *config, log_test_t lt)
 		}
 		if (nv.value == NULL) {
 			fclose(f);
+			audit_msg(LOG_ERR,
+				"Not processing any more lines in %s",
+				CONFIG_FILE);
 			return 1;
 		}
 
@@ -218,14 +222,31 @@ int load_config(struct daemon_conf *config, log_test_t lt)
 	return 0;
 }
 
-static char *get_line(FILE *f, char *buf)
+static char *get_line(FILE *f, char *buf, unsigned size, int *lineno,
+	const char *file)
 {
-	if (fgets_unlocked(buf, 128, f)) {
+	int too_long = 0;
+
+	while (fgets_unlocked(buf, size, f)) {
 		/* remove newline */
 		char *ptr = strchr(buf, 0x0a);
-		if (ptr)
-			*ptr = 0;
-		return buf;
+		if (ptr) {
+			if (!too_long) {
+				*ptr = 0;
+				return buf;
+			}
+			// Reset and start with the next line
+			too_long = 0;
+			*lineno = *lineno + 1;
+		} else {
+		// If a line is too long skip it.
+		// Only output 1 warning
+		if (!too_long)
+			audit_msg(LOG_ERR,
+					"Skipping line %d in %s: too long",
+					*lineno, file);
+			too_long = 1;
+		}
 	}
 	return NULL;
 }
@@ -237,7 +258,7 @@ static int nv_split(char *buf, struct _pair *nv)
 
 	nv->name = NULL;
 	nv->value = NULL;
-	ptr = strtok(buf, " ");
+	ptr = audit_strsplit(buf);
 	if (ptr == NULL)
 		return 0; /* If there's nothing, go to next line */
 	if (ptr[0] == '#')
@@ -245,23 +266,23 @@ static int nv_split(char *buf, struct _pair *nv)
 	nv->name = ptr;
 
 	/* Check for a '=' */
-	ptr = strtok(NULL, " ");
+	ptr = audit_strsplit(NULL);
 	if (ptr == NULL)
 		return 1;
 	if (strcmp(ptr, "=") != 0)
 		return 2;
 
 	/* get the value */
-	ptr = strtok(NULL, " ");
+	ptr = audit_strsplit(NULL);
 	if (ptr == NULL)
 		return 1;
 	nv->value = ptr;
 
 	/* Make sure there's nothing else */
-	ptr = strtok(NULL, " ");
+	ptr = audit_strsplit(NULL);
 	if (ptr) {
 		/* Allow one option, but check that there's not 2 */
-		ptr = strtok(NULL, " ");
+		ptr = audit_strsplit(NULL);
 		if (ptr)
 			return 1;
 	}
