@@ -281,3 +281,7 @@ _S(273, "finit_module")
 _S(274, "sched_setattr")
 _S(275, "sched_getattr")
 _S(276, "renameat2")
+_S(277, "seccomp")
+_S(278, "getrandom")
+_S(279, "memfd_create")
+_S(280, "bpf")
