@@ -372,3 +372,7 @@ _S(350, "finit_module")
 _S(351, "sched_setattr")
 _S(352, "sched_getattr")
 _S(353, "renameat2")
+_S(354, "seccomp")
+_S(355, "getrandom")
+_S(356, "memfd_create")
+_S(357, "bpf")
